@@ -205,6 +205,10 @@ def run(command, verbose, debug, dry_run, no_lock, update,
     '--working-dir', '-w', default=None,
     help='Working directory, when omitted the current directory is used',
     )
+@click.option(
+    '--start-at-step', '-S', type=float, default=1.0,
+    help='When running in step-by-step mode, start processing at the given step number',
+    )
 @click.option(
     '--limit-parallelism', '-l', type=int, default=None,
     help='Limit the parallelism to the given number, unlimitted if omitted',
@@ -212,7 +216,8 @@ def run(command, verbose, debug, dry_run, no_lock, update,
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
 @click.version_option(version=__version__)
 def run_all(command, verbose, debug, dry_run, no_lock, update, exclude_external_dependencies,
-    step_by_step, planfile, auto_approve, working_dir, limit_parallelism, terragrunt_args):
+    step_by_step, planfile, auto_approve, working_dir, start_at_step,
+    limit_parallelism, terragrunt_args):
     """ Executes a terragrunt command across multiple projects """
 
     check_latest_version()
@@ -229,6 +234,7 @@ def run_all(command, verbose, debug, dry_run, no_lock, update, exclude_external_
         planfile=planfile,
         auto_approve=auto_approve,
         working_dir=working_dir,
+        start_at_step=start_at_step,
         limit_parallelism=limit_parallelism,
         terragrunt_args=terragrunt_args,
     )
@@ -302,13 +308,18 @@ def run_import(address, id, verbose, dry_run, working_dir, no_lock, terragrunt_a
     '--working-dir', '-w', default=None,
     help='Working directory, when omitted the current directory is used',
     )
+@click.option(
+    '--start-at-step', '-S', type=float, default=1.0,
+    help='When running in step-by-step mode, start processing at the given step number',
+    )
 @click.option('--out', '-o', is_flag=True, default=False,
     help='Show output as json',
     show_default=True
     )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
 @click.version_option(version=__version__)
-def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, out, terragrunt_args):
+def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, 
+    start_at_step, out, terragrunt_args):
     """ Analyzes the plan files """
 
     check_latest_version()
@@ -318,6 +329,7 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, out, t
         dry_run=dry_run,
         exclude_external_dependencies=exclude_external_dependencies,
         working_dir=working_dir,
+        start_at_step=start_at_step,
         out=out,
         terragrunt_args=terragrunt_args,
     )
