@@ -263,7 +263,7 @@ class TgWrap():
         return stop_processing
 
     def _run_di_graph(
-        self, command, exclude_external_dependencies, dry_run,
+        self, command, exclude_external_dependencies, start_at_step, dry_run,
         ask_for_confirmation=False, collect_output_file=None,
         working_dir=None,
         ):
@@ -295,14 +295,21 @@ class TgWrap():
         stop_processing = False
         nbr_of_groups = len(groups)
         for idx, group in enumerate(groups):
-            
-            self.printer.header(f'Group {idx+1}')
+            group_nbr=idx+1
+            self.printer.header(f'Group {group_nbr}')
             self.printer.normal(group)
 
             if command:
                 nbr_of_modules = len(group)
                 for idx2, module in enumerate(group):
-                    progress = f'module #{idx2+1}/{nbr_of_modules} of group #{idx+1}/{nbr_of_groups}'
+                    module_nbr=idx2+1
+                    progress = f'module #{module_nbr}/{nbr_of_modules} of group #{group_nbr}/{nbr_of_groups}'
+
+                    step_nbr = group_nbr + module_nbr/10
+                    if step_nbr < start_at_step:
+                        self.printer.normal(f'Skip step {step_nbr}, start at {start_at_step}')
+                        continue
+
                     stop_processing = self._run_graph_step(
                         command=command,
                         working_dir=working_dir,
@@ -317,6 +324,8 @@ class TgWrap():
 
             if stop_processing:
                 break
+        
+        self.printer.verbose(f'Executed {group_nbr} groups and {step_nbr} steps')
 
     def _run_sync(
         self, source_path, target_path, source_stage, target_stage, auto_approve,
@@ -414,7 +423,7 @@ class TgWrap():
 
     def run_all(self, command, debug, dry_run, no_lock, update,
         exclude_external_dependencies, step_by_step, planfile, auto_approve, 
-        working_dir, limit_parallelism, terragrunt_args):
+        working_dir, start_at_step, limit_parallelism, terragrunt_args):
         """ Executes a terragrunt command across multiple modules """
 
         self.printer.verbose(f"Attempting to execute 'run-all {command}'")
@@ -449,6 +458,7 @@ class TgWrap():
                 working_dir=working_dir,
                 ask_for_confirmation=(not auto_approve),
                 dry_run=dry_run,
+                start_at_step=start_at_step,
             )
         else:
             if dry_run:
@@ -503,7 +513,8 @@ class TgWrap():
             )
             self.printer.verbose(rc)
 
-    def analyze(self, dry_run, exclude_external_dependencies, working_dir, out, terragrunt_args):
+    def analyze(self, dry_run, exclude_external_dependencies, working_dir,
+        start_at_step, out, terragrunt_args):
         """ Analyzes the plan files """
 
         self.printer.verbose("Attempting to 'analyze'")
@@ -552,6 +563,7 @@ class TgWrap():
                     dry_run=dry_run,
                     collect_output_file=f,
                     working_dir=working_dir,
+                    start_at_step=start_at_step,
                     ask_for_confirmation=False,
                 )
 
